| Title: | Regional and Multi-Regional Input-Output Data |
| Version: | 0.0.1 |
| Description: | Provides Regional (Brazil, 2020) and Multi-Regional (World, 2000) input-output matrices for R. This package serves as a data-only companion to the 'fio' package, facilitating input-output analysis by providing standardized R6 data objects. |
| License: | CC0 |
| URL: | https://github.com/albersonmiranda/fiodata |
| BugReports: | https://github.com/albersonmiranda/fiodata/issues |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| LazyData: | true |
| LazyDataCompression: | xz |
| Depends: | R (≥ 3.5.0) |
| Suggests: | fio |
| NeedsCompilation: | no |
| Packaged: | 2026-02-20 20:03:03 UTC; albersonmiranda |
| Author: | Alberson da Silva Miranda
|
| Maintainer: | Alberson da Silva Miranda <albersonmiranda@hotmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-02-25 10:40:07 UTC |
fiodata: Regional and Multi-Regional Input-Output Data
Description
Provides Regional (Brazil, 2020) and Multi-Regional (World, 2000) input-output matrices for R. This package serves as a data-only companion to the 'fio' package, facilitating input-output analysis by providing standardized R6 data objects.
Author(s)
Maintainer: Alberson da Silva Miranda albersonmiranda@hotmail.com (ORCID) [copyright holder]
Authors:
Celso Bissoli Sessa celso.sessa@ufes.br (ORCID) [data contributor]
See Also
Useful links:
Report bugs at https://github.com/albersonmiranda/fiodata/issues
Brazil input-output matrix, year 2020, 51 sectors
Description
This dataset contains the Brazilian input-output matrix for the year 2020, with 51 sectors. The data is based on the Brazilian Institute of Geography and Statistics (IBGE) and the Brazilian Institute of Applied Economic Research (IPEA).
Usage
br_2020
Format
br_2020
A R6 class containing a set of matrices:
idIdentifier of the new instance
intermediate_transactionsIntermediate transactions matrix.
total_productionTotal production matrix.
final_demandFinal demand matrix.
exportsExports matrix.
importsImports matrix.
taxesTaxes matrix.
value_addedValue added matrix.
Brazilian Institute of Geography and Statistics (IBGE); Brazilian Institute of Applied Economic Research (IPEA); Center for Computational Studies in General Equilibrium (CECEG) at the Federal University of Espírito Santo (UFES).
Examples
# Access the object
br_2020
# View available matrices
names(br_2020)
World input-output matrix, year 2000, 26 countries, 23 sectors.
Description
This dataset contains a world input-output matrix for the year 2000, with 26 countries and 23 sectors. The data was compiled by the Computational General Equilibrium Study Center (CEGEC) at the Federal University of Espírito Santo (Brazil).
Usage
world_2000
Format
world_2000
A R6 class containing a set of matrices:
idIdentifier of the new instance
intermediate_transactionsIntermediate transactions matrix.
total_productionTotal production matrix.
household_consumptionHousehold consumption matrix.
government_consumptionGovernment consumption matrix.
final_demand_othersOther final demand components matrix (GFCF and Stock Variation).
taxesTaxes matrix.
value_added_othersOther value added components matrix (Labor, Capital, Other).
countriesVector with country names.
sectorsVector with sector names.
Computational General Equilibrium Study Center (CEGEC) at the Federal University of Espírito Santo (UFES), Brazil.
Examples
# Access the object
world_2000
# View available components
names(world_2000)